@@ -123,6 +123,9 @@
 #' - recordedBy (RECORDED_BY)
 #' - establishmentMeans (ESTABLISHMENT_MEANS)
 #' - coordinateUncertaintyInMeters (COORDINATE_UNCERTAINTY_IN_METERS)
+#' - gadm (GADM_GID) (for the Database of Global Administrative Areas)
+#' - stateProvince (STATE_PROVINCE)
+#' - occurrenceStatus (OCCURRENCE_STATUS)
 #'
 #' @references Download predicates docs:
 #' <https://www.gbif.org/developer/occurrence#predicates>
@@ -145,6 +148,7 @@
 #' pred_notnull("issue")
 #' pred("basisOfRecord", "LITERATURE")
 #' pred("hasCoordinate", TRUE)
+#' pred("stateProvince", "California")
 #' pred("hasGeospatialIssue", FALSE)
 #' pred_within("POLYGON((-14 42, 9 38, -7 26, -14 42))")
 #' pred_or(pred("taxonKey", 2977832), pred("taxonKey", 2977901),
@@ -271,7 +275,9 @@ key_lkup <- list(taxonKey='TAXON_KEY', scientificName='SCIENTIFIC_NAME',
     institutionCode='INSTITUTION_CODE', collectionCode='COLLECTION_CODE',
     issue='ISSUE', mediatype='MEDIA_TYPE', recordedBy='RECORDED_BY',
     establishmentMeans='ESTABLISHMENT_MEANS',
-    coordinateUncertaintyInMeters='COORDINATE_UNCERTAINTY_IN_METERS')
+    coordinateUncertaintyInMeters='COORDINATE_UNCERTAINTY_IN_METERS',
+    gadm = 'GADM_GID', stateProvince = 'STATE_PROVINCE',
+    occurrenceStatus = 'OCCURRENCE_STATUS')
 
 parse_pred <- function(key, value, type = "and") {
   assert(key, "character")
@@ -291,7 +297,7 @@ parse_pred <- function(key, value, type = "and") {
 
   if (
     (is.character(value) &&
-      all(grepl("polygon|multipolygon|linestring|multilinestring|point|mulitpoint",
+      all(grepl("polygon|multipolygon|linestring|multilinestring|point|multipoint",
         value, ignore.case = TRUE))) ||
     type == "within"
   ) {
